@@ -147,12 +147,12 @@ def get_dummy_vnf_update_config():
 
 
 def get_vim_obj():
-    return {'vim': {'type': 'openstack', 'auth_url':
-                    'http://localhost:5000', 'vim_project': {'name':
-                    'test_project'}, 'auth_cred': {'username': 'test_user',
-                                                   'password':
-                                                       'test_password'},
-                            'name': 'VIM0',
+    return {'vim': {'type': 'openstack', 'auth_url': 'http://localhost:5000',
+                    'vim_project': {'name': 'test_project'},
+                    'auth_cred': {'username': 'test_user',
+                                  'password': 'test_password',
+                                  'cert_verify': 'True'},
+                    'name': 'VIM0',
                     'tenant_id': 'test-project'}}
 
 
@@ -161,6 +161,7 @@ def get_vim_auth_obj():
             'password': 'test_password',
             'project_id': None,
             'project_name': 'test_project',
+            'cert_verify': 'True',
             'auth_url': 'http://localhost:5000/v3',
             'user_domain_name': 'default',
             'project_domain_name': 'default'}
