@@ -18,9 +18,9 @@ import os
 from cryptography import fernet
 from oslo_config import cfg
 from oslo_log import log as logging
-from oslo_log import versionutils
 
 from tacker.extensions import nfvo
+from tacker.keymgr import API as KEYMGR_API
 from tacker import manager
 from tacker.plugins.common import constants
 
@@ -28,19 +28,6 @@ LOG = logging.getLogger(__name__)
 CONF = cfg.CONF
 
 
-OPTS = [
-    cfg.StrOpt(
-        'default_vim', help=_('Default VIM for launching VNFs. '
-        'This option is deprecated and will be removed in Ocata release.'),
-        deprecated_for_removal=True)
-]
-cfg.CONF.register_opts(OPTS, 'nfvo_vim')
-
-
-def config_opts():
-    return [('nfvo_vim', OPTS)]
-
-
 class VimClient(object):
     def get_vim(self, context, vim_id=None, region_name=None):
         """Get Vim information for provided VIM id
@@ -52,33 +39,25 @@ class VimClient(object):
             constants.NFVO)
 
         if not vim_id:
-            LOG.debug(_('VIM id not provided. Attempting to find default '
-                        'VIM information'))
+            LOG.debug('VIM id not provided. Attempting to find default '
+                      'VIM information')
             try:
                 vim_info = nfvo_plugin.get_default_vim(context)
-            except Exception:
-                LOG.debug(_('Default vim not set in db.'
-                    'Attempting to find default vim from tacker.conf'))
-                vim_name = cfg.CONF.nfvo_vim.default_vim
-                if not vim_name:
-                    raise nfvo.VimDefaultNameNotDefined()
-                versionutils.report_deprecated_feature(LOG, 'Configuration of '
-                    'default-vim in tacker.conf is deprecated and will be '
-                    'removed in Newton cycle')
-                vim_info = self._get_default_vim_by_name(context,
-                                                         nfvo_plugin, vim_name)
+            except Exception as ex:
+                LOG.debug('Fail to get default vim due to %s', ex)
+                raise nfvo.VimDefaultNotDefined()
         else:
             try:
                 vim_info = nfvo_plugin.get_vim(context, vim_id,
                                                mask_password=False)
             except Exception:
                 raise nfvo.VimNotFoundException(vim_id=vim_id)
-        LOG.debug(_('VIM info found for vim id %s'), vim_id)
+        LOG.debug('VIM info found for vim id %s', vim_id)
         if region_name and not self.region_valid(vim_info['placement_attr']
                                                  ['regions'], region_name):
             raise nfvo.VimRegionNotFoundException(region_name=region_name)
 
-        vim_auth = self._build_vim_auth(vim_info)
+        vim_auth = self._build_vim_auth(context, vim_info)
         vim_res = {'vim_auth': vim_auth, 'vim_id': vim_info['id'],
                    'vim_name': vim_info.get('name', vim_info['id']),
                    'vim_type': vim_info['type']}
@@ -88,40 +67,49 @@ class VimClient(object):
     def region_valid(vim_regions, region_name):
         return region_name in vim_regions
 
-    # Deprecated. Will be removed in Ocata release
-    def _get_default_vim_by_name(self, context, plugin, vim_name):
-        vim_info = plugin.get_vim_by_name(context, vim_name,
-                                          mask_password=False)
-        if not vim_info:
-            raise nfvo.VimDefaultNameNotFound(vim_name=vim_name)
-        return vim_info
-
-    def _build_vim_auth(self, vim_info):
+    def _build_vim_auth(self, context, vim_info):
         LOG.debug('VIM id is %s', vim_info['id'])
         vim_auth = vim_info['auth_cred']
-        vim_auth['password'] = self._decode_vim_auth(vim_info['id'],
-                                                     vim_auth[
-                                                     'password'].encode(
-                                                         'utf-8'))
+        vim_auth['password'] = self._decode_vim_auth(context,
+                                                     vim_info['id'],
+                                                     vim_auth)
         vim_auth['auth_url'] = vim_info['auth_url']
+
+        # These attributes are needless for authentication
+        # from keystone, so we remove them.
+        needless_attrs = ['key_type', 'secret_uuid']
+        for attr in needless_attrs:
+            if attr in vim_auth:
+                vim_auth.pop(attr, None)
         return vim_auth
 
-    def _decode_vim_auth(self, vim_id, cred):
+    def _decode_vim_auth(self, context, vim_id, auth):
         """Decode Vim credentials
 
-        Decrypt VIM cred. using Fernet Key
+        Decrypt VIM cred, get fernet Key from local_file_system or
+        barbican.
         """
-        vim_key = self._find_vim_key(vim_id)
+        cred = auth['password'].encode('utf-8')
+        if auth.get('key_type') == 'barbican_key':
+            keystone_conf = CONF.keystone_authtoken
+            secret_uuid = auth['secret_uuid']
+            keymgr_api = KEYMGR_API(keystone_conf.auth_url)
+            secret_obj = keymgr_api.get(context, secret_uuid)
+            vim_key = secret_obj.payload
+        else:
+            vim_key = self._find_vim_key(vim_id)
+
         f = fernet.Fernet(vim_key)
         if not f:
-            LOG.warning(_('Unable to decode VIM auth'))
-            raise nfvo.VimNotFoundException('Unable to decode VIM auth key')
+            LOG.warning('Unable to decode VIM auth')
+            raise nfvo.VimNotFoundException(
+                'Unable to decode VIM auth key')
         return f.decrypt(cred)
 
     @staticmethod
     def _find_vim_key(vim_id):
         key_file = os.path.join(CONF.vim_keys.openstack, vim_id)
-        LOG.debug(_('Attempting to open key file for vim id %s'), vim_id)
+        LOG.debug('Attempting to open key file for vim id %s', vim_id)
         with open(key_file, 'r') as f:
                 return f.read()
-        LOG.warning(_('VIM id invalid or key not found for  %s'), vim_id)
+        LOG.warning('VIM id invalid or key not found for  %s', vim_id)
